==> ews-0.0.11.tar.gz: lib/Enumerations/Enumerations.dart <==
export 'AffectedTaskOccurrence.dart';
export 'AggregateType.dart';
export 'AppointmentType.dart';
export 'AutodiscoverEndpoints.dart';
export 'AutodiscoverErrorCode.dart';
export 'AutodiscoverResponseType.dart';
export 'AvailabilityData.dart';
export 'BasePropertySet.dart';
export 'BodyType.dart';
export 'ChangeType.dart';
export 'ClientAccessTokenType.dart';
export 'ClientExtensionProvidedTo.dart';
export 'ComparisonMode.dart';
export 'ConflictResolutionMode.dart';
export 'ConflictType.dart';
export 'ConnectingIdType.dart';
export 'ConnectionFailureCause.dart';
export 'ConsentState.dart';
export 'ContactSource.dart';
export 'ContainmentMode.dart';
export 'ConversationAction.dart';
export 'ConversationFlagStatus.dart';
export 'ConversationQueryTraversal.dart';
export 'ConversationSortOrder.dart';
export 'DateTimePrecision.dart';
export 'DayOfTheWeek.dart';
export 'DayOfTheWeekIndex.dart';
export 'DefaultExtendedPropertySet.dart';
export 'DelegateFolderPermissionLevel.dart';
export 'DeleteMode.dart';
//export 'DnsRecordType.cs
export 'DomainSettingName.dart';
export 'EffectiveRights.dart';
export 'ElcFolderType.dart';
export 'EmailAddressKey.dart';
export 'EmailPosition.dart';
export 'EventType.dart';
export 'ExchangeVersion.dart';
export 'ExtensionInstallScope.dart';
export 'ExtensionType.dart';
export 'FileAsMapping.dart';
export 'FlaggedForAction.dart';
export 'FolderPermissionLevel.dart';
export 'FolderPermissionReadAccess.dart';
export 'FolderTraversal.dart';
export 'FreeBusyViewType.dart';
export 'GetUserPhotoStatus.dart';
export 'HoldAction.dart';
export 'HoldStatus.dart';
export 'IconIndex.dart';
export 'IdFormat.dart';
export 'ImAddressKey.dart';
export 'Importance.dart';
export 'ItemFlagStatus.dart';
export 'ItemTraversal.dart';
export 'LegacyFreeBusyStatus.dart';
export 'LobbyBypass.dart';
export 'LocationSource.dart';
export 'LogicalOperator.dart';
export 'MailboxSearchLocation.dart';
export 'MailboxSearchScopeType.dart';
export 'MailboxType.dart';
export 'MapiPropertyType.dart';
export 'MeetingAttendeeType.dart';
export 'MeetingRequestsDeliveryScope.dart';
export 'MeetingRequestType.dart';
export 'MemberStatus.dart';
export 'MessageDisposition.dart';
export 'Month.dart';
export 'OffsetBasePoint.dart';
export 'OnlineMeetingAccessLevel.dart';
export 'OofExternalAudience.dart';
export 'OofState.dart';
export 'OutlookProtocolType.dart';
export 'PeopleQueryContextKeys.dart';
export 'PeopleQuerySource.dart';
export 'PermissionScope.dart';
export 'PhoneCallState.dart';
export 'PhoneNumberKey.dart';
export 'PhysicalAddressIndex.dart';
export 'PhysicalAddressKey.dart';
export 'Presenters.dart';
export 'PreviewItemBaseShape.dart';
export 'PrivilegedLogonType.dart';
export 'PropertyDefinitionFlags.dart';
export 'ResolveNameSearchLocation.dart';
export 'ResponseActions.dart';
export 'ResponseMessageType.dart';
export 'ResponseType.dart';
export 'RetentionActionType.dart';
export 'RetentionType.dart';
export 'RuleErrorCode.dart';
export 'RuleProperty.dart';
export 'SearchFolderTraversal.dart';
export 'SearchPageDirection.dart';
export 'SearchResultType.dart';
export 'SendCancellationsMode.dart';
export 'SendInvitationsMode.dart';
export 'SendInvitationsOrCancellationsMode.dart';
export 'SendPrompt.dart';
export 'Sensitivity.dart';
export 'ServiceError.dart';
export 'ServiceErrorHandling.dart';
export 'ServiceObjectType.dart';
export 'ServiceResult.dart';
export 'SetClientExtensionActionId.dart';
export 'SortDirection.dart';
export 'StandardUser.dart';
export 'SuggestionQuality.dart';
export 'SyncFolderItemsScope.dart';
export 'TaskDelegationState.dart';
export 'TaskMode.dart';
export 'TaskStatus.dart';
//export 'TeamMailboxLifecycleState.cs
export 'TraceFlags.dart';
//export 'UnifiedGroupEnumTypes.cs
//export 'UserConfigurationDictionaryObjectType.cs
//export 'UserConfigurationProperties.cs
//export 'UserPhotoSize.cs
//export 'UserSettingName.cs
export 'ViewFilter.dart';
export 'WellKnownFolderName.dart';
export 'XmlNamespace.dart';

==> ews-1.0.0.tar.gz: lib/Enumerations/Enumerations.dart <==
export 'AffectedTaskOccurrence.dart';
export 'AggregateType.dart';
export 'AppointmentType.dart';
export 'AutodiscoverEndpoints.dart';
export 'AutodiscoverErrorCode.dart';
export 'AutodiscoverResponseType.dart';
export 'AvailabilityData.dart';
export 'BasePropertySet.dart';
export 'BodyType.dart';
export 'ChangeType.dart';
export 'ClientAccessTokenType.dart';
export 'ClientExtensionProvidedTo.dart';
export 'ComparisonMode.dart';
export 'ConflictResolutionMode.dart';
export 'ConflictType.dart';
export 'ConnectingIdType.dart';
export 'ConnectionFailureCause.dart';
export 'ConsentState.dart';
export 'ContactSource.dart';
export 'ContainmentMode.dart';
export 'ConversationAction.dart';
export 'ConversationFlagStatus.dart';
export 'ConversationQueryTraversal.dart';
export 'ConversationSortOrder.dart';
export 'DateTimePrecision.dart';
export 'DayOfTheWeek.dart';
export 'DayOfTheWeekIndex.dart';
export 'DefaultExtendedPropertySet.dart';
export 'DelegateFolderPermissionLevel.dart';
export 'DeleteMode.dart';
//export 'DnsRecordType.cs
export 'DomainSettingName.dart';
export 'EffectiveRights.dart';
export 'ElcFolderType.dart';
export 'EmailAddressKey.dart';
export 'EmailPosition.dart';
export 'EventType.dart';
export 'ExchangeVersion.dart';
export 'ExtensionInstallScope.dart';
export 'ExtensionType.dart';
export 'FileAsMapping.dart';
export 'FlaggedForAction.dart';
export 'FolderPermissionLevel.dart';
export 'FolderPermissionReadAccess.dart';
export 'FolderTraversal.dart';
export 'FreeBusyViewType.dart';
export 'GetUserPhotoStatus.dart';
export 'HoldAction.dart';
export 'HoldStatus.dart';
export 'IconIndex.dart';
export 'IdFormat.dart';
export 'ImAddressKey.dart';
export 'Importance.dart';
export 'ItemFlagStatus.dart';
export 'ItemTraversal.dart';
export 'LegacyFreeBusyStatus.dart';
export 'LobbyBypass.dart';
export 'LocationSource.dart';
export 'LogicalOperator.dart';
export 'MailboxSearchLocation.dart';
export 'MailboxSearchScopeType.dart';
export 'MailboxType.dart';
export 'MapiPropertyType.dart';
export 'MeetingAttendeeType.dart';
export 'MeetingRequestsDeliveryScope.dart';
export 'MeetingRequestType.dart';
export 'MemberStatus.dart';
export 'MessageDisposition.dart';
export 'Month.dart';
export 'OffsetBasePoint.dart';
export 'OnlineMeetingAccessLevel.dart';
export 'OofExternalAudience.dart';
export 'OofState.dart';
export 'OutlookProtocolType.dart';
export 'PeopleQueryContextKeys.dart';
export 'PeopleQuerySource.dart';
export 'PermissionScope.dart';
export 'PhoneCallState.dart';
export 'PhoneNumberKey.dart';
export 'PhysicalAddressIndex.dart';
export 'PhysicalAddressKey.dart';
export 'Presenters.dart';
export 'PreviewItemBaseShape.dart';
export 'PrivilegedLogonType.dart';
export 'PropertyDefinitionFlags.dart';
export 'ResolveNameSearchLocation.dart';
export 'ResponseActions.dart';
export 'ResponseMessageType.dart';
export 'ResponseType.dart';
export 'RetentionActionType.dart';
export 'RetentionType.dart';
export 'RuleErrorCode.dart';
export 'RuleProperty.dart';
export 'SearchFolderTraversal.dart';
export 'SearchPageDirection.dart';
export 'SearchResultType.dart';
export 'SendCancellationsMode.dart';
export 'SendInvitationsMode.dart';
export 'SendInvitationsOrCancellationsMode.dart';
export 'SendPrompt.dart';
export 'Sensitivity.dart';
export 'ServiceError.dart';
export 'ServiceErrorHandling.dart';
export 'ServiceObjectType.dart';
export 'ServiceResult.dart';
export 'SetClientExtensionActionId.dart';
export 'SortDirection.dart';
export 'StandardUser.dart';
export 'SuggestionQuality.dart';
export 'SyncFolderItemsScope.dart';
export 'TaskDelegationState.dart';
export 'TaskMode.dart';
export 'TaskStatus.dart';
//export 'TeamMailboxLifecycleState.cs
export 'TraceFlags.dart';
//export 'UnifiedGroupEnumTypes.cs
//export 'UserConfigurationDictionaryObjectType.cs
//export 'UserConfigurationProperties.cs
//export 'UserPhotoSize.cs
//export 'UserSettingName.dart
export 'ViewFilter.dart';
export 'WellKnownFolderName.dart';
export 'XmlNamespace.dart';
